@@ -1,7 +1,5 @@
 from six.moves.urllib.parse import urljoin
 import sys
-
-sys.path.append('c:\AngelSmartApi\SmartApi')
 import csv
 import json
 import dateutil.parser
@@ -20,10 +18,10 @@ log = logging.getLogger(__name__)
 
 
 class SmartConnect(object):
-    _rootUrl = "https://openapisuat.angelbroking.com"
-    #_rootUrl="https://apiconnect.angelbroking.com"
-    _login_url ="https://smartapi.angelbroking.com/login"
-    #_login_url="https://smartapi.angelbroking.com/publisher-login"
+    #_rootUrl = "https://openapisuat.angelbroking.com"
+    _rootUrl="https://apiconnect.angelbroking.com" #prod endpoint
+    #_login_url ="https://smartapi.angelbroking.com/login"
+    _login_url="https://smartapi.angelbroking.com/publisher-login" #prod endpoint
     _default_timeout = 7  # In seconds
     # Products
     PRODUCT_MIS = "MIS"
@@ -276,7 +274,15 @@ class SmartConnect(object):
 
         if "jwtToken" in response:
             tokenSet['jwtToken']=response['data']['jwtToken']
+<<<<<<< HEAD
+<<<<<<< HEAD
         tokenSet['clientcode']=self. userId   
+=======
+        tokenSet['clientcode']=self.userId
+>>>>>>> d8cd1ced0e9e79452791072bec4213ec85e370b1
+=======
+        tokenSet['clientcode']=self. userId   
+>>>>>>> develop
         tokenSet['refreshToken']=response['data']["refreshToken"]
        
         return tokenSet
