@@ -8,10 +8,9 @@ dir = os.getcwd()
 sys.path.append(dir + "\SmartApi")
 #print(sys.path)
 
-from smartapi import SmartConnect
+from smartapi.smartConnect import SmartConnect
 
-smartApi =
-SmartConnect()
+smartApi =SmartConnect()
 
 login = smartApi.generateSession('D88311', 'Angel@444')
 print(login)
@@ -73,7 +72,7 @@ params={
 smartApi.convertPosition(params)
 smartApi.terminateSession('D88311')
 
-from smartapi import SmartSocket
+from smartapi.smartSocket import SmartSocket
 FEED_TOKEN='1731759952'
 CLIENT_CODE='S212741'
 token=None
